@@ -31,6 +31,8 @@ public:
     ~ImportExportVCardTest();
 private Q_SLOTS:
     void shouldExportFullTestVcard4();
+    void shouldExportMiscElementVcard4();
+    void shouldExportMemberElementVcard4();
 };
 
 #endif // IMPORTEXPORTVCARDTEST_H
